@@ -89,6 +89,7 @@ use strict;
 use Carp                  ();
 use Process               ();
 use File::Spec            ();
+use File::Spec::Unix      ();
 use File::Which           ();
 use File::Remove          ();
 use Config::Tiny          ();
@@ -102,7 +103,7 @@ use PITA::Image::Test     ();
 
 use vars qw{$VERSION @ISA $NOSERVER};
 BEGIN {
-	$VERSION = '0.42';
+	$VERSION = '0.43';
 	@ISA     = 'Process';
 }
 
@@ -436,7 +437,7 @@ sub report_task_uri {
 	my ($self, $task) = @_;
 	my $uri  = $self->server_uri;
 	my $job  = $task->job_id;
-	my $path = File::Spec->catfile( $uri->path || '/', $job );
+	my $path = File::Spec::Unix->catfile( $uri->path || '/', $job );
 	$uri->path( $path );
 	$uri;
 }
@@ -495,7 +496,7 @@ L<PITA>, L<PITA::XML>, L<PITA::Scheme>
 
 =head1 COPYRIGHT
 
-Copyright 2005 - 2009 Adam Kennedy.
+Copyright 2005 - 2011 Adam Kennedy.
 
 This program is free software; you can redistribute
 it and/or modify it under the same terms as Perl itself.
